@@ -1,5 +1,6 @@
 import logging
 import time
+import os
 
 from cleargrid.util.subprocess import ProcessManager
 
@@ -31,7 +32,10 @@ def start():
         p.start()
         time.sleep(2)
 
-    ProcessManager(args=["start", "chrome", "http://127.0.0.1/app/"]).start()
+    ProcessManager(
+        "Start Chrome",
+        [os.environ["COMSPEC"], "/C", 'start chrome "http://127.0.0.1/app/"'],
+    ).start()
 
     try:
         while True:
